# ShapG: a fast and exactly approach to approximate the Shaple value on graph

If you find this code useful in your research, please consider citing:

```
@article{zhao2024investigationcentralitymeasuresopinion,
      title={Investigation on centrality measures and opinion dynamics in two-layer networks with replica nodes}, 
      author={Chi Zhao and Elena Parilina},
      year={2024},
      eprint={2406.18780},
      archivePrefix={arXiv},
      primaryClass={physics.soc-ph},
      journal={arXiv preprint arXiv:2406.18780},
      url={https://arxiv.org/abs/2406.18780}, 
}
```